import {NumberRange, FastMountainRenderableSeries, XyDataSeries,ZoomPanModifier,EXyDirection,MouseWheelZoomModifier,NumericAxis,SciChartJSLightTheme, SciChartSurface, parseColorToUIntArgb, DefaultPaletteProvider, EStrokePaletteMode} from 'scichart'

SciChartSurface.UseCommunityLicense();
SciChartSurface.useWasmFromCDN();

const init = async () => {
  const {wasmContext, sciChartSurface} = await SciChartSurface.create('container', {theme: new SciChartJSLightTheme()})
  console.log(sciChartSurface.currentWebGlRenderContext);

  const xAxis = new NumericAxis(wasmContext, {drawMajorBands: false, drawMajorGridLines: false, drawMinorGridLines: false});
  const yAxis = new NumericAxis(wasmContext, {drawMajorBands: false, drawMajorGridLines: false, drawMinorGridLines: false});

  sciChartSurface.xAxes.add(xAxis)
  sciChartSurface.yAxes.add(yAxis)

  sciChartSurface.chartModifiers.add(new MouseWheelZoomModifier({xyDirection: EXyDirection.XDirection}))
  sciChartSurface.chartModifiers.add(new ZoomPanModifier({xyDirection: EXyDirection.XDirection}))

  const array = new Array(50_000).fill(0).map(val => Math.max(Math.random(), 0));
  const array2 = new Array(50_000).fill(0).map((val, index) => index);

  const dataSeries = new XyDataSeries(wasmContext)
  dataSeries.appendRange(array2, array);

  const series = new FastMountainRenderableSeries(wasmContext, {
    stroke: '#005B96',
    fill: '#005B96',
    strokeThickness: 0.1,
    zeroLineY: 0,
    dataSeries,
  })

  sciChartSurface.renderableSeries.add(series);

  setInterval(() => {
  
    
    const axis = sciChartSurface.xAxes.get(0);
    const prev = axis.visibleRange;
    axis.visibleRange = new NumberRange(prev.min + 1, prev.max + 1);
  }, 100)
}

init();